/*requires Schema.SQLGeneration.sql*/


PRINT '--------------------------------------------------------------------------------------------------------------'
PRINT 'Table [SQLGeneration].[ExecutionLog] Creation'

IF  NOT EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[SQLGeneration].[ExecutionLog]') AND type in (N'U'))
BEGIN
    CREATE TABLE [SQLGeneration].[ExecutionLog] (
        [GenerationId]          BIGINT IDENTITY(1,1),
        [PurposeName]           [VARCHAR](512)  NOT NULL,
        [SQLLogin]              [VARCHAR](512)  NOT NULL,
        [ClientNetAddress]      [VARCHAR](128)  NOT NULL,
        [ClientHostName]        [VARCHAR](128)  NOT NULL,
        [ClientProgramName]     [VARCHAR](256)  NOT NULL,
        [StartTime]             [DATETIME]      NOT NULL,
        [EndTime]               [DATETIME]      NULL,
        [ValidForNbDays]        INT             NULL,
        [GenerationParams]      [VARCHAR](MAX)  NULL,
        [Outcome]               [VARCHAR](64)   NULL,
        [ErrorDetails]          [VARCHAR](MAX)  NULL
    )
    ON [PRIMARY]

    IF @@ERROR = 0
        PRINT '   Table created.'
    ELSE
    BEGIN
        PRINT '   Error while trying to create table.'
        RETURN
    END
END
GO

/**
    Adding a column to a given table 
 */
DECLARE @ColumnName     VARCHAR(128)    = QUOTENAME('ErrorDetails')
DECLARE @ColumnDef      NVARCHAR(MAX)   = '[VARCHAR](MAX)  NULL'
DECLARE @FullTableName  NVARCHAR(MAX)   = N'[SQLGeneration].[ExecutionLog]'
DECLARE @tsql           NVARCHAR(max)

IF NOT EXISTS( 
    SELECT 1 
    FROM  sys.columns 
    WHERE QUOTENAME(Name) = @ColumnName and Object_ID = Object_ID(@FullTableName)
)
BEGIN
    SET @tsql = N'ALTER TABLE ' + @FullTableName + ' ADD ' + @ColumnName +' ' + @ColumnDef
    execute sp_executesql @tsql
    
    PRINT '    Column ' + @ColumnName + ' added.'
END
GO


DECLARE @tsql NVARCHAR(MAX)
IF (OBJECTPROPERTY( OBJECT_ID( '[SQLGeneration].[ExecutionLog]' ), 'TableHasPrimaryKey' ) <> 1)
BEGIN
    SET @tsql = '
    ALTER TABLE [SQLGeneration].[ExecutionLog] 
        ADD  CONSTRAINT [PK_ExecutionLog] 
            PRIMARY KEY (
                [GenerationId]
            )'
    exec sp_executesql @tsql
    IF @@ERROR = 0
        PRINT '   Primary Key [PK_ExecutionLog] created.'
END
GO

PRINT '--------------------------------------------------------------------------------------------------------------'
PRINT ''
